@@ -171,6 +171,27 @@ class PTUsersView(generic.ObjectView):
     queryset = models.PTUsers.objects.all()
     template_name = 'ptuevents/ptusers.html'
 
+    def get_extra_context(self, request, instance):
+        print(self)
+        print(request)
+        print(instance.id)
+
+        content_type_id = ContentType.objects.get_for_model(
+            model=models.PTUsers).id
+        PTUEvent_ass = models.PTUEventAssignment.objects.filter(
+            object_id=instance.id, content_type=content_type_id)
+        PTUEvents = []
+        for r in PTUEvent_ass:
+            PTUEvents.append({
+                'assignment_id': r.id,
+                'name': r.ptuevent,
+                'rel': r.relation.name
+            })
+
+        return {
+            'PTUEvents': PTUEvents
+        }
+
 
 class PTUsersListView(generic.ObjectListView):
     queryset = models.PTUsers.objects.all()
@@ -192,6 +213,27 @@ class PTWorkstationsView(generic.ObjectView):
     queryset = models.PTWorkstations.objects.all()
     template_name = 'ptuevents/ptworkstations.html'
 
+    def get_extra_context(self, request, instance):
+        print(self)
+        print(request)
+        print(instance.id)
+
+        content_type_id = ContentType.objects.get_for_model(
+                model=models.PTWorkstations).id
+        PTUEvent_ass = models.PTUEventAssignment.objects.filter(
+                object_id=instance.id, content_type=content_type_id)
+        PTUEvents = []
+        for r in PTUEvent_ass:
+            PTUEvents.append({
+                'assignment_id': r.id,
+                'name'         : r.ptuevent,
+                'rel'          : r.relation.name
+            })
+
+        return {
+            'PTUEvents': PTUEvents
+        }
+
 
 class PTWorkstationsListView(generic.ObjectListView):
     queryset = models.PTWorkstations.objects.all()
